<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'île de l’Ascension',
    'AX' => 'îles d’Åland',
    'BN' => 'Brunéi',
    'BY' => 'Bélarus',
    'BZ' => 'Bélize',
    'CC' => 'îles Cocos (Keeling)',
    'CK' => 'îles Cook',
    'CX' => 'île Christmas',
    'FK' => 'îles Malouines',
    'FO' => 'îles Féroé',
    'IC' => 'îles Canaries',
    'IM' => 'île de Man',
    'KG' => 'Kirghizistan',
    'KN' => 'Saint‑Kitts‑et‑Nevis',
    'LR' => 'Libéria',
    'MF' => 'Saint-Martin (France)',
    'MM' => 'Myanmar',
    'MP' => 'Mariannes du Nord',
    'NF' => 'île Norfolk',
    'NG' => 'Nigéria',
    'PN' => 'îles Pitcairn',
    'RE' => 'la Réunion',
    'SX' => 'Saint-Martin (Pays-Bas)',
    'TL' => 'Timor-Leste',
    'UM' => 'îles mineures éloignées des États-Unis',
    'VA' => 'Cité du Vatican',
    'VE' => 'Vénézuéla',
    'VG' => 'îles Vierges britanniques',
    'VI' => 'îles Vierges américaines',
    'VN' => 'Vietnam',
];
