<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Острів Вознесіння',
    'AD' => 'Андорра',
    'AE' => 'Обʼєднані Арабські Емірати',
    'AF' => 'Афганістан',
    'AG' => 'Антигуа і Барбуда',
    'AI' => 'Ангілья',
    'AL' => 'Албанія',
    'AM' => 'Вірменія',
    'AO' => 'Ангола',
    'AQ' => 'Антарктика',
    'AR' => 'Аргентина',
    'AS' => 'Американське Самоа',
    'AT' => 'Австрія',
    'AU' => 'Австралія',
    'AW' => 'Аруба',
    'AX' => 'Аландські Острови',
    'AZ' => 'Азербайджан',
    'BA' => 'Боснія і Герцеговина',
    'BB' => 'Барбадос',
    'BD' => 'Бангладеш',
    'BE' => 'Бельгія',
    'BF' => 'Буркіна-Фасо',
    'BG' => 'Болгарія',
    'BH' => 'Бахрейн',
    'BI' => 'Бурунді',
    'BJ' => 'Бенін',
    'BL' => 'Сен-Бартелемі',
    'BM' => 'Бермудські Острови',
    'BN' => 'Бруней',
    'BO' => 'Болівія',
    'BQ' => 'Карибські Нідерланди',
    'BR' => 'Бразилія',
    'BS' => 'Багамські Острови',
    'BT' => 'Бутан',
    'BW' => 'Ботсвана',
    'BY' => 'Білорусь',
    'BZ' => 'Беліз',
    'CA' => 'Канада',
    'CC' => 'Кокосові (Кілінг) Острови',
    'CD' => 'Конго – Кіншаса',
    'CF' => 'Центральноафриканська Республіка',
    'CG' => 'Конго – Браззавіль',
    'CH' => 'Швейцарія',
    'CI' => 'Кот-дʼІвуар',
    'CK' => 'Острови Кука',
    'CL' => 'Чилі',
    'CM' => 'Камерун',
    'CN' => 'Китай',
    'CO' => 'Колумбія',
    'CR' => 'Коста-Рика',
    'CU' => 'Куба',
    'CV' => 'Кабо-Верде',
    'CW' => 'Кюрасао',
    'CX' => 'Острів Різдва',
    'CY' => 'Кіпр',
    'CZ' => 'Чехія',
    'DE' => 'Німеччина',
    'DG' => 'Дієго-Гарсія',
    'DJ' => 'Джибуті',
    'DK' => 'Данія',
    'DM' => 'Домініка',
    'DO' => 'Домініканська Республіка',
    'DZ' => 'Алжир',
    'EA' => 'Сеута і Мелілья',
    'EC' => 'Еквадор',
    'EE' => 'Естонія',
    'EG' => 'Єгипет',
    'EH' => 'Західна Сахара',
    'ER' => 'Еритрея',
    'ES' => 'Іспанія',
    'ET' => 'Ефіопія',
    'FI' => 'Фінляндія',
    'FJ' => 'Фіджі',
    'FK' => 'Фолклендські Острови',
    'FM' => 'Мікронезія',
    'FO' => 'Фарерські Острови',
    'FR' => 'Франція',
    'GA' => 'Габон',
    'GB' => 'Велика Британія',
    'GD' => 'Гренада',
    'GE' => 'Грузія',
    'GF' => 'Французька Гвіана',
    'GG' => 'Гернсі',
    'GH' => 'Гана',
    'GI' => 'Гібралтар',
    'GL' => 'Гренландія',
    'GM' => 'Гамбія',
    'GN' => 'Гвінея',
    'GP' => 'Гваделупа',
    'GQ' => 'Екваторіальна Гвінея',
    'GR' => 'Греція',
    'GS' => 'Південна Джорджія та Південні Сандвічеві Острови',
    'GT' => 'Гватемала',
    'GU' => 'Гуам',
    'GW' => 'Гвінея-Бісау',
    'GY' => 'Гаяна',
    'HK' => 'Гонконг, ОАР Китаю',
    'HN' => 'Гондурас',
    'HR' => 'Хорватія',
    'HT' => 'Гаїті',
    'HU' => 'Угорщина',
    'IC' => 'Канарські Острови',
    'ID' => 'Індонезія',
    'IE' => 'Ірландія',
    'IL' => 'Ізраїль',
    'IM' => 'Острів Мен',
    'IN' => 'Індія',
    'IO' => 'Британська територія в Індійському океані',
    'IQ' => 'Ірак',
    'IR' => 'Іран',
    'IS' => 'Ісландія',
    'IT' => 'Італія',
    'JE' => 'Джерсі',
    'JM' => 'Ямайка',
    'JO' => 'Йорданія',
    'JP' => 'Японія',
    'KE' => 'Кенія',
    'KG' => 'Киргизстан',
    'KH' => 'Камбоджа',
    'KI' => 'Кірибаті',
    'KM' => 'Комори',
    'KN' => 'Сент-Кітс і Невіс',
    'KP' => 'Північна Корея',
    'KR' => 'Південна Корея',
    'KW' => 'Кувейт',
    'KY' => 'Кайманові Острови',
    'KZ' => 'Казахстан',
    'LA' => 'Лаос',
    'LB' => 'Ліван',
    'LC' => 'Сент-Люсія',
    'LI' => 'Ліхтенштейн',
    'LK' => 'Шрі-Ланка',
    'LR' => 'Ліберія',
    'LS' => 'Лесото',
    'LT' => 'Литва',
    'LU' => 'Люксембург',
    'LV' => 'Латвія',
    'LY' => 'Лівія',
    'MA' => 'Марокко',
    'MC' => 'Монако',
    'MD' => 'Молдова',
    'ME' => 'Чорногорія',
    'MF' => 'Сен-Мартен',
    'MG' => 'Мадагаскар',
    'MH' => 'Маршаллові Острови',
    'MK' => 'Північна Македонія',
    'ML' => 'Малі',
    'MM' => 'Мʼянма (Бірма)',
    'MN' => 'Монголія',
    'MO' => 'Макао, ОАР Китаю',
    'MP' => 'Північні Маріанські Острови',
    'MQ' => 'Мартиніка',
    'MR' => 'Мавританія',
    'MS' => 'Монтсеррат',
    'MT' => 'Мальта',
    'MU' => 'Маврикій',
    'MV' => 'Мальдіви',
    'MW' => 'Малаві',
    'MX' => 'Мексика',
    'MY' => 'Малайзія',
    'MZ' => 'Мозамбік',
    'NA' => 'Намібія',
    'NC' => 'Нова Каледонія',
    'NE' => 'Нігер',
    'NF' => 'Острів Норфолк',
    'NG' => 'Нігерія',
    'NI' => 'Нікарагуа',
    'NL' => 'Нідерланди',
    'NO' => 'Норвегія',
    'NP' => 'Непал',
    'NR' => 'Науру',
    'NU' => 'Ніуе',
    'NZ' => 'Нова Зеландія',
    'OM' => 'Оман',
    'PA' => 'Панама',
    'PE' => 'Перу',
    'PF' => 'Французька Полінезія',
    'PG' => 'Папуа-Нова Гвінея',
    'PH' => 'Філіппіни',
    'PK' => 'Пакистан',
    'PL' => 'Польща',
    'PM' => 'Сен-Пʼєр і Мікелон',
    'PN' => 'Острови Піткерн',
    'PR' => 'Пуерто-Рико',
    'PS' => 'Палестинські території',
    'PT' => 'Португалія',
    'PW' => 'Палау',
    'PY' => 'Парагвай',
    'QA' => 'Катар',
    'RE' => 'Реюньйон',
    'RO' => 'Румунія',
    'RS' => 'Сербія',
    'RU' => 'Росія',
    'RW' => 'Руанда',
    'SA' => 'Саудівська Аравія',
    'SB' => 'Соломонові Острови',
    'SC' => 'Сейшельські Острови',
    'SD' => 'Судан',
    'SE' => 'Швеція',
    'SG' => 'Сінгапур',
    'SH' => 'Острів Святої Єлени',
    'SI' => 'Словенія',
    'SJ' => 'Шпіцберген та Ян-Маєн',
    'SK' => 'Словаччина',
    'SL' => 'Сьєрра-Леоне',
    'SM' => 'Сан-Марино',
    'SN' => 'Сенегал',
    'SO' => 'Сомалі',
    'SR' => 'Суринам',
    'SS' => 'Південний Судан',
    'ST' => 'Сан-Томе і Принсіпі',
    'SV' => 'Сальвадор',
    'SX' => 'Сінт-Мартен',
    'SY' => 'Сирія',
    'SZ' => 'Есватіні',
    'TA' => 'Трістан-да-Кунья',
    'TC' => 'Острови Теркс і Кайкос',
    'TD' => 'Чад',
    'TF' => 'Французькі Південні Території',
    'TG' => 'Того',
    'TH' => 'Таїланд',
    'TJ' => 'Таджикистан',
    'TK' => 'Токелау',
    'TL' => 'Тимор-Лешті',
    'TM' => 'Туркменістан',
    'TN' => 'Туніс',
    'TO' => 'Тонга',
    'TR' => 'Туреччина',
    'TT' => 'Тринідад і Тобаго',
    'TV' => 'Тувалу',
    'TW' => 'Тайвань',
    'TZ' => 'Танзанія',
    'UA' => 'Україна',
    'UG' => 'Уганда',
    'UM' => 'Віддалені острови США',
    'US' => 'Сполучені Штати',
    'UY' => 'Уругвай',
    'UZ' => 'Узбекистан',
    'VA' => 'Ватикан',
    'VC' => 'Сент-Вінсент і Гренадіни',
    'VE' => 'Венесуела',
    'VG' => 'Британські Віргінські острови',
    'VI' => 'Віргінські Острови (США)',
    'VN' => 'Вʼєтнам',
    'VU' => 'Вануату',
    'WF' => 'Уолліс і Футуна',
    'WS' => 'Самоа',
    'XK' => 'Косово',
    'YE' => 'Ємен',
    'YT' => 'Майотта',
    'ZA' => 'Південно-Африканська Республіка',
    'ZM' => 'Замбія',
    'ZW' => 'Зімбабве',
];
