<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'BR' => 'بئرئزیل',
    'CN' => 'چین',
    'DE' => 'آلمان',
    'FR' => 'فأرانسە',
    'GB' => 'بیریتانیا گأپ',
    'IN' => 'ھئن',
    'IT' => 'ئیتالیا',
    'JP' => 'جاپوٙن',
    'RU' => 'روٙسیە',
    'US' => 'ڤولاتیا یأکاگئرتە',
];
