<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'طلوع ٻيٽ',
    'AD' => 'اندورا',
    'AE' => 'متحده عرب امارات',
    'AF' => 'افغانستان',
    'AG' => 'انٽيگا ۽ باربد',
    'AI' => 'انگويلا',
    'AL' => 'البانيا',
    'AM' => 'ارمینیا',
    'AO' => 'انگولا',
    'AQ' => 'انٽارڪٽيڪا',
    'AR' => 'ارجنٽينا',
    'AS' => 'آمريڪي ساموا',
    'AT' => 'آسٽريا',
    'AU' => 'آسٽريليا',
    'AW' => 'عروبا',
    'AX' => 'الند ٻيٽ',
    'AZ' => 'آذربائيجان',
    'BA' => 'بوسنيا ۽ هرزوگووينا',
    'BB' => 'باربڊوس',
    'BD' => 'بنگلاديش',
    'BE' => 'بيلجيم',
    'BF' => 'برڪينا فاسو',
    'BG' => 'بلغاريا',
    'BH' => 'بحرين',
    'BI' => 'برونڊي',
    'BJ' => 'بينن',
    'BL' => 'سینٽ برٿلیمی',
    'BM' => 'برمودا',
    'BN' => 'برونائي',
    'BO' => 'بوليويا',
    'BQ' => 'ڪيريبين نيدرلينڊ',
    'BR' => 'برازيل',
    'BS' => 'باهاماس',
    'BT' => 'ڀوٽان',
    'BW' => 'بوٽسوانا',
    'BY' => 'بیلارس',
    'BZ' => 'بيليز',
    'CA' => 'ڪينيڊا',
    'CC' => 'ڪوڪوس ٻيٽ',
    'CD' => 'ڪانگو -ڪنشاسا',
    'CF' => 'وچ آفريقي جمهوريه',
    'CG' => 'ڪانگو - برازاویل',
    'CH' => 'سوئزرلينڊ',
    'CI' => 'ڪوٽي ويرا',
    'CK' => 'ڪوڪ ٻيٽ',
    'CL' => 'چلي',
    'CM' => 'ڪيمرون',
    'CN' => 'چين',
    'CO' => 'ڪولمبيا',
    'CR' => 'ڪوسٽا ريڪا',
    'CU' => 'ڪيوبا',
    'CV' => 'ڪيپ وردي',
    'CW' => 'ڪيوراسائو',
    'CX' => 'ڪرسمس ٻيٽ',
    'CY' => 'سائپرس',
    'CZ' => 'چيڪيا',
    'DE' => 'جرمني',
    'DG' => 'ڊئيگو گارسيا',
    'DJ' => 'ڊجبيوتي',
    'DK' => 'ڊينمارڪ',
    'DM' => 'ڊومينيڪا',
    'DO' => 'ڊومينيڪن جمهوريه',
    'DZ' => 'الجيريا',
    'EA' => 'سیوٽا ۽ میلیلا',
    'EC' => 'ايڪواڊور',
    'EE' => 'ايسٽونيا',
    'EG' => 'مصر',
    'EH' => 'اولهه صحارا',
    'ER' => 'ايريٽيريا',
    'ES' => 'اسپين',
    'ET' => 'ايٿوپيا',
    'FI' => 'فن لينڊ',
    'FJ' => 'فجي',
    'FK' => 'فاڪ لينڊ ٻيٽ',
    'FM' => 'مائڪرونيشيا',
    'FO' => 'فارو ٻيٽ',
    'FR' => 'فرانس',
    'GA' => 'گبون',
    'GB' => 'برطانيہ',
    'GD' => 'گريناڊا',
    'GE' => 'جارجيا',
    'GF' => 'فرانسيسي گيانا',
    'GG' => 'گورنسي',
    'GH' => 'گهانا',
    'GI' => 'جبرالٽر',
    'GL' => 'گرين لينڊ',
    'GM' => 'گيمبيا',
    'GN' => 'گني',
    'GP' => 'گواڊیلوپ',
    'GQ' => 'ايڪوٽوريل گائينا',
    'GR' => 'يونان',
    'GS' => 'ڏکڻ جارجيا ۽ ڏکڻ سينڊوچ ٻيٽ',
    'GT' => 'گوئٽي مالا',
    'GU' => 'گوام',
    'GW' => 'گني بسائو',
    'GY' => 'گيانا',
    'HK' => 'هانگ ڪانگ SAR',
    'HN' => 'هنڊورس',
    'HR' => 'ڪروئيشيا',
    'HT' => 'هيٽي',
    'HU' => 'هنگري',
    'IC' => 'ڪينري ٻيٽ',
    'ID' => 'انڊونيشيا',
    'IE' => 'آئرلينڊ',
    'IL' => 'اسرائيل',
    'IM' => 'انسانن جو ٻيٽ',
    'IN' => 'ڀارت',
    'IO' => 'برطانوي هندي سمنڊ خطو',
    'IQ' => 'عراق',
    'IR' => 'ايران',
    'IS' => 'آئس لينڊ',
    'IT' => 'اٽلي',
    'JE' => 'جرسي',
    'JM' => 'جميڪا',
    'JO' => 'اردن',
    'JP' => 'جاپان',
    'KE' => 'ڪينيا',
    'KG' => 'ڪرغستان',
    'KH' => 'ڪمبوڊيا',
    'KI' => 'ڪرباتي',
    'KM' => 'ڪوموروس',
    'KN' => 'سينٽ ڪٽس و نيوس',
    'KP' => 'اتر ڪوريا',
    'KR' => 'ڏکڻ ڪوريا',
    'KW' => 'ڪويت',
    'KY' => 'ڪي مين ٻيٽ',
    'KZ' => 'قازقستان',
    'LA' => 'لائوس',
    'LB' => 'لبنان',
    'LC' => 'سينٽ لوسيا',
    'LI' => 'لچي ٽينسٽين',
    'LK' => 'سري لنڪا',
    'LR' => 'لائبیریا',
    'LS' => 'ليسوٿو',
    'LT' => 'لٿونيا',
    'LU' => 'لگزمبرگ',
    'LV' => 'لاتويا',
    'LY' => 'لبيا',
    'MA' => 'مراڪش',
    'MC' => 'موناڪو',
    'MD' => 'مالدووا',
    'ME' => 'مونٽي نيگرو',
    'MF' => 'سينٽ مارٽن',
    'MG' => 'مدگاسڪر',
    'MH' => 'مارشل ٻيٽ',
    'MK' => 'اتر مقدونيا',
    'ML' => 'مالي',
    'MM' => 'ميانمار (برما)',
    'MN' => 'منگوليا',
    'MO' => 'مڪائو SAR چين',
    'MP' => 'اتريان ماريانا ٻيٽ',
    'MQ' => 'مارتينڪ',
    'MR' => 'موريتانيا',
    'MS' => 'مونٽسراٽ',
    'MT' => 'مالٽا',
    'MU' => 'موريشس',
    'MV' => 'مالديپ',
    'MW' => 'مالاوي',
    'MX' => 'ميڪسيڪو',
    'MY' => 'ملائيشيا',
    'MZ' => 'موزمبیق',
    'NA' => 'نيميبيا',
    'NC' => 'نیو ڪالیڊونیا',
    'NE' => 'نائيجر',
    'NF' => 'نورفوڪ ٻيٽ',
    'NG' => 'نائيجيريا',
    'NI' => 'نڪراگوا',
    'NL' => 'نيدرلينڊ',
    'NO' => 'ناروي',
    'NP' => 'نيپال',
    'NR' => 'نائورو',
    'NU' => 'نووي',
    'NZ' => 'نيو زيلينڊ',
    'OM' => 'عمان',
    'PA' => 'پناما',
    'PE' => 'پيرو',
    'PF' => 'فرانسيسي پولينيشيا',
    'PG' => 'پاپوا نیو گني',
    'PH' => 'فلپائن',
    'PK' => 'پاڪستان',
    'PL' => 'پولينڊ',
    'PM' => 'سینٽ پیئر و میڪوئیلون',
    'PN' => 'پٽڪئرن ٻيٽ',
    'PR' => 'پيوئرٽو ريڪو',
    'PS' => 'فلسطيني علائقا',
    'PT' => 'پرتگال',
    'PW' => 'پلائو',
    'PY' => 'پيراگوءِ',
    'QA' => 'قطر',
    'RE' => 'ري يونين',
    'RO' => 'رومانيا',
    'RS' => 'سربيا',
    'RU' => 'روس',
    'RW' => 'روانڊا',
    'SA' => 'سعودي عرب',
    'SB' => 'سولومون ٻيٽَ',
    'SC' => 'شي شلز',
    'SD' => 'سوڊان',
    'SE' => 'سوئيڊن',
    'SG' => 'سنگاپور',
    'SH' => 'سينٽ ھيلينا',
    'SI' => 'سلوینیا',
    'SJ' => 'سوالبارڊ ۽ جان ماین',
    'SK' => 'سلوواڪيا',
    'SL' => 'سيرا ليون',
    'SM' => 'سین مرینو',
    'SN' => 'سينيگال',
    'SO' => 'سوماليا',
    'SR' => 'سورينام',
    'SS' => 'ڏکڻ سوڊان',
    'ST' => 'سائو ٽوم ۽ پرنسپیي',
    'SV' => 'ال سلواڊور',
    'SX' => 'سنٽ مارٽن',
    'SY' => 'شام',
    'SZ' => 'ايسواٽني',
    'TA' => 'ٽرسٽن دا ڪوها',
    'TC' => 'ترڪ ۽ ڪيڪوس ٻيٽ',
    'TD' => 'چاڊ',
    'TF' => 'فرانسيسي ڏاکڻي علائقا',
    'TG' => 'ٽوگو',
    'TH' => 'ٿائيليند',
    'TJ' => 'تاجڪستان',
    'TK' => 'ٽوڪلائو',
    'TL' => 'تيمور ليستي',
    'TM' => 'ترڪمانستان',
    'TN' => 'تيونيسيا',
    'TO' => 'ٽونگا',
    'TR' => 'ترڪييي',
    'TT' => 'ٽريني ڊيڊ ۽ ٽوباگو ٻيٽ',
    'TV' => 'توالو',
    'TW' => 'تائیوان',
    'TZ' => 'تنزانيا',
    'UA' => 'يوڪرين',
    'UG' => 'يوگنڊا',
    'UM' => 'آمريڪي خارجي ٻيٽ',
    'US' => 'آمريڪا جون گڏيل رياستون',
    'UY' => 'يوروگوءِ',
    'UZ' => 'ازبڪستان',
    'VA' => 'ويٽڪين سٽي',
    'VC' => 'سینٽ ونسنت ۽ گریناڊینز',
    'VE' => 'وينزويلا',
    'VG' => 'برطانوي ورجن ٻيٽ',
    'VI' => 'آمريڪي ورجن ٻيٽ',
    'VN' => 'ويتنام',
    'VU' => 'وينيٽيو',
    'WF' => 'والس ۽ فتونا',
    'WS' => 'ساموا',
    'XK' => 'ڪوسووو',
    'YE' => 'يمن',
    'YT' => 'مياتي',
    'ZA' => 'ڏکڻ آفريقا',
    'ZM' => 'زيمبيا',
    'ZW' => 'زمبابوي',
];
