<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'CN' => 'Chin',
    'CY' => 'Siprus',
    'DE' => 'Jermon',
    'EG' => 'Ejipt',
    'ES' => 'Ispania',
    'FR' => 'Frans',
    'GR' => 'Gres',
    'IN' => 'Bharot',
    'IT' => 'Italia',
    'LY' => 'Libia',
    'MK' => 'Ut’tor Masedonia',
    'RU' => 'Roxya',
];
