<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'دوورگەی ئاسینسیۆن',
    'AD' => 'ئاندۆرا',
    'AE' => 'میرنشینە یەکگرتووە عەرەبییەکان',
    'AF' => 'ئەفغانستان',
    'AG' => 'ئانتیگوا و باربودا',
    'AI' => 'ئانگویلا',
    'AL' => 'ئەڵبانیا',
    'AM' => 'ئەرمەنستان',
    'AO' => 'ئەنگۆلا',
    'AQ' => 'ئانتارکتیکا',
    'AR' => 'ئەرژەنتین',
    'AS' => 'ساموای ئەمەریکایی',
    'AT' => 'نەمسا',
    'AU' => 'ئوسترالیا',
    'AW' => 'ئارووبا',
    'AX' => 'دوورگەکانی ئالاند',
    'AZ' => 'ئازەربایجان',
    'BA' => 'بۆسنیا و ھەرزەگۆڤینا',
    'BB' => 'باربادۆس',
    'BD' => 'بەنگلادیش',
    'BE' => 'بەلژیک',
    'BF' => 'بورکینافاسۆ',
    'BG' => 'بولگاریا',
    'BH' => 'بەحرەین',
    'BI' => 'بوروندی',
    'BJ' => 'بێنین',
    'BL' => 'سەن بارتێلێمی',
    'BM' => 'بێرموودا',
    'BN' => 'بروونای',
    'BO' => 'بۆلیڤیا',
    'BQ' => 'دوورگە کاریبیەکانی هۆڵەندا',
    'BR' => 'برازیل',
    'BS' => 'بەھاما',
    'BT' => 'بووتان',
    'BW' => 'بۆتسوانا',
    'BY' => 'بیلاڕووس',
    'BZ' => 'بەلیز',
    'CA' => 'کەنەدا',
    'CC' => 'دوورگەکانی کیلینگ',
    'CD' => 'کۆنگۆ کینشاسا',
    'CF' => 'کۆماری ئەفریقای ناوەڕاست',
    'CG' => 'کۆنگۆ برازاڤیل',
    'CH' => 'سویسڕا',
    'CI' => 'کۆتدیڤوار',
    'CK' => 'دوورگەکانی کوک',
    'CL' => 'چیلی',
    'CM' => 'کامیرۆن',
    'CN' => 'چین',
    'CO' => 'کۆلۆمبیا',
    'CR' => 'کۆستاریکا',
    'CU' => 'کووبا',
    'CV' => 'کەیپڤەرد',
    'CW' => 'کوراچاو',
    'CX' => 'دوورگەی کریسمس',
    'CY' => 'قیبرس',
    'CZ' => 'کۆماری چیک',
    'DE' => 'ئەڵمانیا',
    'DG' => 'دیەگۆ گارسیا',
    'DJ' => 'جیبووتی',
    'DK' => 'دانمارک',
    'DM' => 'دۆمینیکا',
    'DO' => 'کۆماری دۆمینیکا',
    'DZ' => 'جەزایر',
    'EA' => 'سێئووتا و مێلییا',
    'EC' => 'ئیکوادۆر',
    'EE' => 'ئیستۆنیا',
    'EG' => 'میسر',
    'EH' => 'سەحرای ڕۆژاوا',
    'ER' => 'ئەریتریا',
    'ES' => 'ئیسپانیا',
    'ET' => 'ئەتیۆپیا',
    'FI' => 'فینلاند',
    'FJ' => 'فیجی',
    'FK' => 'دوورگەکانی مالڤیناس (دوورگەکانی فاڵکلاند)',
    'FM' => 'مایکرۆنیزیا',
    'FO' => 'دوورگەکانی فارەو',
    'FR' => 'فەڕەنسا',
    'GA' => 'گابۆن',
    'GB' => 'شانشینی یەکگرتوو',
    'GD' => 'گرینادا',
    'GE' => 'گورجستان',
    'GF' => 'گیانای فەرەنسا',
    'GG' => 'گێرنزی',
    'GH' => 'غەنا',
    'GI' => 'گیبرالتار',
    'GL' => 'گرینلاند',
    'GM' => 'گامبیا',
    'GN' => 'گینێ',
    'GP' => 'گوادێلۆپ',
    'GQ' => 'گینێی ئیستوایی',
    'GR' => 'یۆنان',
    'GS' => 'دوورگەکانی جۆرجیا و ساندویچی باشوور',
    'GT' => 'گواتیمالا',
    'GU' => 'گوام',
    'GW' => 'گینێ بیساو',
    'GY' => 'گویانا',
    'HK' => 'هۆنگ کۆنگ',
    'HN' => 'ھۆندووراس',
    'HR' => 'کرۆواتیا',
    'HT' => 'ھایتی',
    'HU' => 'هەنگاریا',
    'IC' => 'دوورگەکانی کەناری',
    'ID' => 'ئیندۆنیزیا',
    'IE' => 'ئیرلەند',
    'IL' => 'ئیسرائیل',
    'IM' => 'دوورگەی مان',
    'IN' => 'ھیندستان',
    'IQ' => 'عێراق',
    'IR' => 'ئێران',
    'IS' => 'ئایسلەند',
    'IT' => 'ئیتالیا',
    'JE' => 'جێرسی',
    'JM' => 'جامایکا',
    'JO' => 'ئوردن',
    'JP' => 'ژاپۆن',
    'KE' => 'کینیا',
    'KG' => 'کرگیزستان',
    'KH' => 'کەمبۆدیا',
    'KI' => 'کیریباس',
    'KM' => 'دوورگەکانی کۆمۆر',
    'KN' => 'سەن کیتس و نیڤیس',
    'KP' => 'کۆریای باکوور',
    'KR' => 'کۆریای باشوور',
    'KW' => 'کوەیت',
    'KY' => 'دوورگەکانی کایمان',
    'KZ' => 'کازاخستان',
    'LA' => 'لاوس',
    'LB' => 'لوبنان',
    'LC' => 'سەن لووسیا',
    'LI' => 'لیختنشتاین',
    'LK' => 'سریلانکا',
    'LR' => 'لیبەریا',
    'LS' => 'لەسۆتۆ',
    'LT' => 'لیتوانایا',
    'LU' => 'لوکسەمبورگ',
    'LV' => 'لاتڤیا',
    'LY' => 'لیبیا',
    'MA' => 'مەغریب',
    'MC' => 'مۆناکۆ',
    'MD' => 'مۆلدۆڤا',
    'ME' => 'مۆنتینیگرۆ',
    'MF' => 'سەن مارتین',
    'MG' => 'ماداگاسکار',
    'MH' => 'دوورگەکانی مارشاڵ',
    'MK' => 'مەکدۆنیای باکوور',
    'ML' => 'مالی',
    'MM' => 'میانمار',
    'MN' => 'مەنگۆلیا',
    'MO' => 'ماکائۆ',
    'MP' => 'دوورگەکانی ماریانای باکوور',
    'MQ' => 'مارتینیک',
    'MR' => 'مۆریتانیا',
    'MS' => 'مۆنتسێرات',
    'MT' => 'ماڵتا',
    'MU' => 'مووریتیووس',
    'MV' => 'مالدیڤ',
    'MW' => 'مالاوی',
    'MX' => 'مەکسیک',
    'MY' => 'مالیزیا',
    'MZ' => 'مۆزامبیک',
    'NA' => 'نامیبیا',
    'NC' => 'نیووکالێدۆنیا',
    'NE' => 'نیجەر',
    'NF' => 'دوورگەی نۆرفۆڵک',
    'NG' => 'نیجریا',
    'NI' => 'نیکاراگوا',
    'NL' => 'ھۆڵەندا',
    'NO' => 'نۆرویژ',
    'NP' => 'نیپال',
    'NR' => 'نائوروو',
    'NU' => 'نیووئی',
    'NZ' => 'نیوزیلاند',
    'OM' => 'عومان',
    'PA' => 'پاناما',
    'PE' => 'پێروو',
    'PF' => 'پۆلینیسیای فەرەنسا',
    'PG' => 'پاپوا گینێی نوێ',
    'PH' => 'فلیپین',
    'PK' => 'پاکستان',
    'PL' => 'پۆڵەندا',
    'PM' => 'سەن پیێر و میکێلۆن',
    'PN' => 'دوورگەکانی پیتکەرن',
    'PR' => 'پۆرتۆڕیکۆ',
    'PS' => 'ناوچە فەلەستینیەکان',
    'PT' => 'پورتوگال',
    'PW' => 'پالاو',
    'PY' => 'پاراگوای',
    'QA' => 'قەتەر',
    'RE' => 'ڕییوونیەن',
    'RO' => 'ڕۆمانیا',
    'RS' => 'سربیا',
    'RU' => 'ڕووسیا',
    'RW' => 'ڕواندا',
    'SA' => 'عەرەبستانی سەعوودی',
    'SB' => 'دوورگەکانی سلێمان',
    'SC' => 'سیشێل',
    'SD' => 'سوودان',
    'SE' => 'سوید',
    'SG' => 'سینگاپور',
    'SH' => 'سەن هێلێنا',
    'SI' => 'سلۆڤێنیا',
    'SJ' => 'سڤالبارد و یان مایەن',
    'SK' => 'سلۆڤاکیا',
    'SL' => 'سیەرالیۆن',
    'SM' => 'سان مارینۆ',
    'SN' => 'سێنێگاڵ',
    'SO' => 'سۆمالیا',
    'SR' => 'سورینام',
    'SS' => 'سوودانی باشوور',
    'ST' => 'ساوتۆمێ و پرینسیپی',
    'SV' => 'ئێلسالڤادۆر',
    'SX' => 'سینت مارتن',
    'SY' => 'سووریا',
    'SZ' => 'سوازیلاند',
    'TA' => 'تریستێن دا کوونا',
    'TC' => 'دوورگەکانی تورکس و کایکۆس',
    'TD' => 'چاد',
    'TF' => 'هەرێمە باشووریەکانی فەرەنسا',
    'TG' => 'تۆگۆ',
    'TH' => 'تایلەند',
    'TJ' => 'تاجیکستان',
    'TK' => 'تۆکێلاو',
    'TL' => 'تیمۆری ڕۆژھەڵات',
    'TM' => 'تورکمانستان',
    'TN' => 'توونس',
    'TO' => 'تۆنگا',
    'TR' => 'تورکیا',
    'TT' => 'ترینیداد و تۆباگو',
    'TV' => 'تووڤالوو',
    'TW' => 'تایوان',
    'TZ' => 'تانزانیا',
    'UA' => 'ئۆکرانیا',
    'UG' => 'ئوگاندا',
    'UM' => 'دوورگەکانی دەرەوەی ئەمریکا',
    'US' => 'ویلایەتە یەکگرتووەکان',
    'UY' => 'ئوروگوای',
    'UZ' => 'ئوزبەکستان',
    'VA' => 'ڤاتیکان',
    'VC' => 'سەینت ڤینسەنت و گرینادینز',
    'VE' => 'ڤەنزوێلا',
    'VG' => 'دوورگەکانی ڤیرجنی بەریتانیا',
    'VI' => 'دوورگەکانی ڤیرجنی ئەمەریکا',
    'VN' => 'ڤیەتنام',
    'VU' => 'ڤانوواتوو',
    'WF' => 'والیس و فوتونا',
    'WS' => 'ساموا',
    'XK' => 'کۆسۆڤۆ',
    'YE' => 'یەمەن',
    'YT' => 'مایۆت',
    'ZA' => 'ئەفریقای باشوور',
    'ZM' => 'زامبیا',
    'ZW' => 'زیمبابوی',
];
