<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'جزیرہ اسینشن',
    'AX' => 'جزائر آلینڈ',
    'CC' => 'جزائر (کیلنگ) کوکوس',
    'CK' => 'جزائر کک',
    'DG' => 'ڈیگو گارشیا',
    'FK' => 'جزائر فاکلینڈ',
    'FO' => 'جزائر فیرو',
    'GF' => 'فرانسیسی گیانا',
    'IC' => 'جزائر کناری',
    'MH' => 'جزائر مارشل',
    'MP' => 'جزائر شمالی ماریانا',
    'NF' => 'جزیرہ نارفوک',
    'PN' => 'جزائر پٹکیرن',
    'SB' => 'جزائر سلیمان',
    'TA' => 'ترسٹان دا کونیا',
    'TC' => 'جزائر کیکس و ترکیہ',
    'UM' => 'امریکی بیرونی جزائر',
    'VG' => 'برطانوی جزائر ورجن',
    'VI' => 'امریکی جزائر ورجن',
];
