<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Ascension',
    'AD' => 'Andorra',
    'AE' => 'Zjednoćene arabske emiraty',
    'AF' => 'Afghanistan',
    'AG' => 'Antigua a Barbuda',
    'AI' => 'Anguilla',
    'AL' => 'Albanska',
    'AM' => 'Armenska',
    'AO' => 'Angola',
    'AQ' => 'Antarktika',
    'AR' => 'Argentinska',
    'AS' => 'Ameriska Samoa',
    'AT' => 'Awstriska',
    'AU' => 'Awstralska',
    'AW' => 'Aruba',
    'AX' => 'Åland',
    'AZ' => 'Azerbajdźan',
    'BA' => 'Bosniska a Hercegowina',
    'BB' => 'Barbados',
    'BD' => 'Bangladeš',
    'BE' => 'Belgiska',
    'BF' => 'Burkina Faso',
    'BG' => 'Bołharska',
    'BH' => 'Bahrain',
    'BI' => 'Burundi',
    'BJ' => 'Benin',
    'BL' => 'St. Barthélemy',
    'BM' => 'Bermudy',
    'BN' => 'Brunei',
    'BO' => 'Boliwiska',
    'BQ' => 'Karibiska Nižozemska',
    'BR' => 'Brazilska',
    'BS' => 'Bahamy',
    'BT' => 'Bhutan',
    'BW' => 'Botswana',
    'BY' => 'Běłoruska',
    'BZ' => 'Belize',
    'CA' => 'Kanada',
    'CC' => 'Kokosowe kupy',
    'CD' => 'Kongo-Kinshasa',
    'CF' => 'Centralnoafriska republika',
    'CG' => 'Kongo-Brazzaville',
    'CH' => 'Šwicarska',
    'CI' => 'Côte d’Ivoire',
    'CK' => 'Cookowe kupy',
    'CL' => 'Chilska',
    'CM' => 'Kamerun',
    'CN' => 'China',
    'CO' => 'Kolumbiska',
    'CR' => 'Kosta Rika',
    'CU' => 'Kuba',
    'CV' => 'Kap Verde',
    'CW' => 'Curaçao',
    'CX' => 'Hodowna kupa',
    'CY' => 'Cypern',
    'CZ' => 'Čěska republika',
    'DE' => 'Němska',
    'DG' => 'Diego Garcia',
    'DJ' => 'Dźibuti',
    'DK' => 'Danska',
    'DM' => 'Dominika',
    'DO' => 'Dominikanska republika',
    'DZ' => 'Algeriska',
    'EA' => 'Ceuta a Melilla',
    'EC' => 'Ekwador',
    'EE' => 'Estiska',
    'EG' => 'Egyptowska',
    'EH' => 'Zapadna Sahara',
    'ER' => 'Eritreja',
    'ES' => 'Španiska',
    'ET' => 'Etiopiska',
    'FI' => 'Finska',
    'FJ' => 'Fidźi',
    'FK' => 'Falklandske kupy',
    'FM' => 'Mikroneziska',
    'FO' => 'Färöske kupy',
    'FR' => 'Francoska',
    'GA' => 'Gabun',
    'GB' => 'Zjednoćene kralestwo',
    'GD' => 'Grenada',
    'GE' => 'Georgiska',
    'GF' => 'Francoska Guyana',
    'GG' => 'Guernsey',
    'GH' => 'Ghana',
    'GI' => 'Gibraltar',
    'GL' => 'Grönlandska',
    'GM' => 'Gambija',
    'GN' => 'Gineja',
    'GP' => 'Guadeloupe',
    'GQ' => 'Ekwatorialna Gineja',
    'GR' => 'Grjekska',
    'GS' => 'Južna Georgiska a Južne Sandwichowe kupy',
    'GT' => 'Guatemala',
    'GU' => 'Guam',
    'GW' => 'Gineja-Bissau',
    'GY' => 'Guyana',
    'HK' => 'Wosebita zarjadniska cona Hongkong',
    'HN' => 'Honduras',
    'HR' => 'Chorwatska',
    'HT' => 'Haiti',
    'HU' => 'Madźarska',
    'IC' => 'Kanariske kupy',
    'ID' => 'Indoneska',
    'IE' => 'Irska',
    'IL' => 'Israel',
    'IM' => 'Man',
    'IN' => 'Indiska',
    'IO' => 'Britiski teritorij w Indiskim oceanje',
    'IQ' => 'Irak',
    'IR' => 'Iran',
    'IS' => 'Islandska',
    'IT' => 'Italska',
    'JE' => 'Jersey',
    'JM' => 'Jamaika',
    'JO' => 'Jordaniska',
    'JP' => 'Japanska',
    'KE' => 'Kenija',
    'KG' => 'Kirgizistan',
    'KH' => 'Kambodźa',
    'KI' => 'Kiribati',
    'KM' => 'Komory',
    'KN' => 'St. Kitts a Nevis',
    'KP' => 'Sewjerna Koreja',
    'KR' => 'Južna Koreja',
    'KW' => 'Kuwait',
    'KY' => 'Kajmanske kupy',
    'KZ' => 'Kazachstan',
    'LA' => 'Laos',
    'LB' => 'Libanon',
    'LC' => 'St. Lucia',
    'LI' => 'Liechtenstein',
    'LK' => 'Sri Lanka',
    'LR' => 'Liberija',
    'LS' => 'Lesotho',
    'LT' => 'Litawska',
    'LU' => 'Luxemburgska',
    'LV' => 'Letiska',
    'LY' => 'Libyska',
    'MA' => 'Marokko',
    'MC' => 'Monaco',
    'MD' => 'Moldawska',
    'ME' => 'Montenegro',
    'MF' => 'St. Martin',
    'MG' => 'Madagaskar',
    'MH' => 'Marshallowe kupy',
    'MK' => 'Serwjerna Makedonska',
    'ML' => 'Mali',
    'MM' => 'Myanmar',
    'MN' => 'Mongolska',
    'MO' => 'Wosebita zarjadniska cona Macao',
    'MP' => 'Sewjerne Mariany',
    'MQ' => 'Martinique',
    'MR' => 'Mawretanska',
    'MS' => 'Montserrat',
    'MT' => 'Malta',
    'MU' => 'Mauritius',
    'MV' => 'Malediwy',
    'MW' => 'Malawi',
    'MX' => 'Mexiko',
    'MY' => 'Malajzija',
    'MZ' => 'Mosambik',
    'NA' => 'Namibija',
    'NC' => 'Nowa Kaledoniska',
    'NE' => 'Niger',
    'NF' => 'Norfolkowa kupa',
    'NG' => 'Nigerija',
    'NI' => 'Nikaragua',
    'NL' => 'Nižozemska',
    'NO' => 'Norwegska',
    'NP' => 'Nepal',
    'NR' => 'Nauru',
    'NU' => 'Niue',
    'NZ' => 'Nowoseelandska',
    'OM' => 'Oman',
    'PA' => 'Panama',
    'PE' => 'Peru',
    'PF' => 'Francoska Polyneziska',
    'PG' => 'Papuwa-Nowa Gineja',
    'PH' => 'Filipiny',
    'PK' => 'Pakistan',
    'PL' => 'Pólska',
    'PM' => 'St. Pierre a Miquelon',
    'PN' => 'Pitcairnowe kupy',
    'PR' => 'Puerto Rico',
    'PS' => 'Palestinski awtonomny teritorij',
    'PT' => 'Portugalska',
    'PW' => 'Palau',
    'PY' => 'Paraguay',
    'QA' => 'Katar',
    'RE' => 'Réunion',
    'RO' => 'Rumunska',
    'RS' => 'Serbiska',
    'RU' => 'Ruska',
    'RW' => 'Ruanda',
    'SA' => 'Sawdi-Arabska',
    'SB' => 'Salomony',
    'SC' => 'Seychelle',
    'SD' => 'Sudan',
    'SE' => 'Šwedska',
    'SG' => 'Singapur',
    'SH' => 'St. Helena',
    'SI' => 'Słowjenska',
    'SJ' => 'Svalbard a Jan Mayen',
    'SK' => 'Słowakska',
    'SL' => 'Sierra Leone',
    'SM' => 'San Marino',
    'SN' => 'Senegal',
    'SO' => 'Somalija',
    'SR' => 'Surinam',
    'SS' => 'Južny Sudan',
    'ST' => 'São Tomé a Príncipe',
    'SV' => 'El Salvador',
    'SX' => 'Sint Maarten',
    'SY' => 'Syriska',
    'SZ' => 'Swaziska',
    'TA' => 'Tristan da Cunha',
    'TC' => 'kupy Turks a Caicos',
    'TD' => 'Čad',
    'TF' => 'Francoski južny a antarktiski teritorij',
    'TG' => 'Togo',
    'TH' => 'Thailandska',
    'TJ' => 'Tadźikistan',
    'TK' => 'Tokelau',
    'TL' => 'Timor-Leste',
    'TM' => 'Turkmeniska',
    'TN' => 'Tuneziska',
    'TO' => 'Tonga',
    'TR' => 'Turkowska',
    'TT' => 'Trinidad a Tobago',
    'TV' => 'Tuvalu',
    'TW' => 'Taiwan',
    'TZ' => 'Tansanija',
    'UA' => 'Ukraina',
    'UG' => 'Uganda',
    'UM' => 'Ameriska Oceaniska',
    'US' => 'Zjednoćene staty Ameriki',
    'UY' => 'Uruguay',
    'UZ' => 'Uzbekistan',
    'VA' => 'Vatikanske město',
    'VC' => 'St. Vincent a Grenadiny',
    'VE' => 'Venezuela',
    'VG' => 'Britiske knježniske kupy',
    'VI' => 'Ameriske knježniske kupy',
    'VN' => 'Vietnam',
    'VU' => 'Vanuatu',
    'WF' => 'Wallis a Futuna',
    'WS' => 'Samoa',
    'XK' => 'Kosowo',
    'YE' => 'Jemen',
    'YT' => 'Mayotte',
    'ZA' => 'Južna Afrika (Republika)',
    'ZM' => 'Sambija',
    'ZW' => 'Simbabwe',
];
