<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Erékùsù Ascension',
    'AD' => 'Ààndórà',
    'AE' => 'Ẹmirate ti Awọn Arabu',
    'AF' => 'Àfùgànístánì',
    'AG' => 'Ààntígúà àti Báríbúdà',
    'AI' => 'Ààngúlílà',
    'AL' => 'Àlùbàníánì',
    'AM' => 'Améníà',
    'AO' => 'Ààngólà',
    'AQ' => 'Antakítíkà',
    'AR' => 'Agentínà',
    'AS' => 'Sámóánì ti Orílẹ́ède Àméríkà',
    'AT' => 'Asítíríà',
    'AU' => 'Austrálíà',
    'AW' => 'Árúbà',
    'AX' => 'Àwọn Erékùsù ti Aland',
    'AZ' => 'Asẹ́bájánì',
    'BA' => 'Bọ̀síníà àti Ẹtisẹgófínà',
    'BB' => 'Bábádósì',
    'BD' => 'Bángáládésì',
    'BE' => 'Bégíọ́mù',
    'BF' => 'Bùùkíná Fasò',
    'BG' => 'Bùùgáríà',
    'BH' => 'Báránì',
    'BI' => 'Bùùrúndì',
    'BJ' => 'Bẹ̀nẹ̀',
    'BL' => 'Ìlú Bátílẹ́mì',
    'BM' => 'Bémúdà',
    'BN' => 'Búrúnẹ́lì',
    'BO' => 'Bọ̀lífíyà',
    'BQ' => 'Kàríbíánì ti Nẹ́dálándì',
    'BR' => 'Bàràsílì',
    'BS' => 'Bàhámásì',
    'BT' => 'Bútánì',
    'BW' => 'Bọ̀tìsúwánà',
    'BY' => 'Bélárúsì',
    'BZ' => 'Bèlísẹ̀',
    'CA' => 'Kánádà',
    'CC' => 'Erékùsù Cocos (Keeling)',
    'CD' => 'Kóńgò – Kinshasa',
    'CF' => 'Àrin gùngun Áfíríkà',
    'CG' => 'Kóńgò – Brazaville',
    'CH' => 'switiṣilandi',
    'CI' => 'Kóútè forà',
    'CK' => 'Etíokun Kùúkù',
    'CL' => 'Ṣílè',
    'CM' => 'Kamerúúnì',
    'CN' => 'Ṣáínà',
    'CO' => 'Kòlómíbìa',
    'CR' => 'Kuusita Ríkà',
    'CU' => 'Kúbà',
    'CV' => 'Etíokun Kápé féndè',
    'CW' => 'Curaçao',
    'CX' => 'Erékùsù Christmas',
    'CY' => 'Kúrúsì',
    'CZ' => 'Ṣẹ́ẹ́kì',
    'DE' => 'Jámánì',
    'DG' => 'Diego Gaṣia',
    'DJ' => 'Díbọ́ótì',
    'DK' => 'Dẹ́mákì',
    'DM' => 'Dòmíníkà',
    'DO' => 'Dòmíníkánì',
    'DZ' => 'Àlùgèríánì',
    'EA' => 'Seuta àti Melilla',
    'EC' => 'Ekuádò',
    'EE' => 'Esitonia',
    'EG' => 'Égípítì',
    'EH' => 'Ìwọ̀òòrùn Sàhárà',
    'ER' => 'Eritira',
    'ES' => 'Sípéìnì',
    'ET' => 'Etopia',
    'FI' => 'Filandi',
    'FJ' => 'Fíjì',
    'FK' => 'Etikun Fakalandi',
    'FM' => 'Makoronesia',
    'FO' => 'Àwọn Erékùsù ti Faroe',
    'FR' => 'Faranse',
    'GA' => 'Gabon',
    'GB' => 'Gẹ̀ẹ́sì',
    'GD' => 'Genada',
    'GE' => 'Gọgia',
    'GF' => 'Firenṣi Guana',
    'GG' => 'Guernsey',
    'GH' => 'Gana',
    'GI' => 'Gibaratara',
    'GL' => 'Gerelandi',
    'GM' => 'Gambia',
    'GN' => 'Gene',
    'GP' => 'Gadelope',
    'GQ' => 'Ekutoria Gini',
    'GR' => 'Gíríìsì',
    'GS' => 'Gúúsù Georgia àti Gúúsù Àwọn Erékùsù Sandwich',
    'GT' => 'Guatemálà',
    'GU' => 'Guamu',
    'GW' => 'Gene-Busau',
    'GY' => 'Guyana',
    'HK' => 'Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí',
    'HN' => 'Hondurasi',
    'HR' => 'Kòróátíà',
    'HT' => 'Haati',
    'HU' => 'Hungari',
    'IC' => 'Ẹrékùsù Kánárì',
    'ID' => 'Indonéṣíà',
    'IE' => 'Ailandi',
    'IL' => 'Iserẹli',
    'IM' => 'Erékùṣù ilẹ̀ Man',
    'IN' => 'Íńdíà',
    'IO' => 'Etíkun Índíánì ti Ìlú Bírítísì',
    'IQ' => 'Iraki',
    'IR' => 'Irani',
    'IS' => 'Aṣilandi',
    'IT' => 'Itáli',
    'JE' => 'Jẹsì',
    'JM' => 'Jamaika',
    'JO' => 'Jọdani',
    'JP' => 'Japani',
    'KE' => 'Kenya',
    'KG' => 'Kuriṣisitani',
    'KH' => 'Kàmùbódíà',
    'KI' => 'Kiribati',
    'KM' => 'Kòmòrósì',
    'KN' => 'Kiiti ati Neefi',
    'KP' => 'Guusu Kọria',
    'KR' => 'Ariwa Kọria',
    'KW' => 'Kuweti',
    'KY' => 'Etíokun Kámánì',
    'KZ' => 'Kaṣaṣatani',
    'LA' => 'Laosi',
    'LB' => 'Lebanoni',
    'LC' => 'Luṣia',
    'LI' => 'Lẹṣitẹnisiteni',
    'LK' => 'Siri Lanka',
    'LR' => 'Laberia',
    'LS' => 'Lesoto',
    'LT' => 'Lituania',
    'LU' => 'Lusemogi',
    'LV' => 'Latifia',
    'LY' => 'Libiya',
    'MA' => 'Moroko',
    'MC' => 'Monako',
    'MD' => 'Modofia',
    'ME' => 'Montenégrò',
    'MF' => 'Ìlú Màtìnì',
    'MG' => 'Madasika',
    'MH' => 'Etikun Máṣali',
    'MK' => 'Àríwá Macedonia',
    'ML' => 'Mali',
    'MM' => 'Manamari',
    'MN' => 'Mogolia',
    'MO' => 'Agbègbè Ìṣàkóso Pàtàkì Macao',
    'MP' => 'Etikun Guusu Mariana',
    'MQ' => 'Matinikuwi',
    'MR' => 'Maritania',
    'MS' => 'Motserati',
    'MT' => 'Malata',
    'MU' => 'Maritiusi',
    'MV' => 'Maladifi',
    'MW' => 'Malawi',
    'MX' => 'Mesiko',
    'MY' => 'Malasia',
    'MZ' => 'Moṣamibiku',
    'NA' => 'Namibia',
    'NC' => 'Kaledonia Titun',
    'NE' => 'Nàìjá',
    'NF' => 'Erékùsù Nọ́úfókì',
    'NG' => 'Nàìjíríà',
    'NI' => 'Nikaragua',
    'NL' => 'Nedalandi',
    'NO' => 'Nọọwii',
    'NP' => 'Nepa',
    'NR' => 'Nauru',
    'NU' => 'Niue',
    'NZ' => 'Ṣilandi Titun',
    'OM' => 'Ọọma',
    'PA' => 'Paramá',
    'PE' => 'Pèérù',
    'PF' => 'Firenṣi Polinesia',
    'PG' => 'Paapu ti Giini',
    'PH' => 'Filipini',
    'PK' => 'Pakisitan',
    'PL' => 'Polandi',
    'PM' => 'Pẹẹri ati mikuloni',
    'PN' => 'Pikarini',
    'PR' => 'Pọto Riko',
    'PS' => 'Agbègbè ara Palẹsítínì',
    'PT' => 'Pọ́túgà',
    'PW' => 'Paalu',
    'PY' => 'Paraguye',
    'QA' => 'Kota',
    'RE' => 'Riuniyan',
    'RO' => 'Romaniya',
    'RS' => 'Sẹ́bíà',
    'RU' => 'Rọṣia',
    'RW' => 'Ruwanda',
    'SA' => 'Saudi Arabia',
    'SB' => 'Etikun Solomoni',
    'SC' => 'Ṣeṣẹlẹsi',
    'SD' => 'Sudani',
    'SE' => 'Swidini',
    'SG' => 'Singapo',
    'SH' => 'Hẹlena',
    'SI' => 'Silofania',
    'SJ' => 'Sífábáàdì àti Jánì Máyẹ̀nì',
    'SK' => 'Silofakia',
    'SL' => 'Siria looni',
    'SM' => 'Sani Marino',
    'SN' => 'Sẹnẹga',
    'SO' => 'Somalia',
    'SR' => 'Surinami',
    'SS' => 'Gúúsù Sudan',
    'ST' => 'Sao tomi ati piriiṣipi',
    'SV' => 'Ẹẹsáfádò',
    'SX' => 'Síntì Mátẹ́ẹ̀nì',
    'SY' => 'Siria',
    'SZ' => 'Saṣiland',
    'TA' => 'Tristan da Kunha',
    'TC' => 'Tọọki ati Etikun Kakọsi',
    'TD' => 'Ṣààdì',
    'TF' => 'Agbègbè Gúúsù Faranṣé',
    'TG' => 'Togo',
    'TH' => 'Tailandi',
    'TJ' => 'Takisitani',
    'TK' => 'Tokelau',
    'TL' => 'Tímọ̀ Lẹsiti',
    'TM' => 'Tọ́kìmẹ́nísítànì',
    'TN' => 'Tuniṣia',
    'TO' => 'Tonga',
    'TR' => 'Tọọki',
    'TT' => 'Tirinida ati Tobaga',
    'TV' => 'Tufalu',
    'TW' => 'Taiwani',
    'TZ' => 'Tàǹsáníà',
    'UA' => 'Ukarini',
    'UG' => 'Uganda',
    'UM' => 'Àwọn Erékùsù Kékèké Agbègbè US',
    'US' => 'Amẹrikà',
    'UY' => 'Úrúgúwè',
    'UZ' => 'Nṣibẹkisitani',
    'VA' => 'Ìlú Vatican',
    'VC' => 'Fisẹnnti ati Genadina',
    'VE' => 'Fẹnẹṣuẹla',
    'VG' => 'Etíkun Fágínì ti ìlú Bírítísì',
    'VI' => 'Etikun Fagini ti Amẹrika',
    'VN' => 'Fẹtinami',
    'VU' => 'Faniatu',
    'WF' => 'Wali ati futuna',
    'WS' => 'Samọ',
    'XK' => 'Kòsófò',
    'YE' => 'Yemeni',
    'YT' => 'Mayote',
    'ZA' => 'Gúúṣù Áfíríkà',
    'ZM' => 'Ṣamibia',
    'ZW' => 'Ṣimibabe',
];
