<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AU' => 'Nūhōlani',
    'CA' => 'Kanakā',
    'CN' => 'Kina',
    'DE' => 'Kelemānia',
    'DK' => 'Kenemaka',
    'ES' => 'Kepania',
    'FR' => 'Palani',
    'GB' => 'Aupuni Mōʻī Hui Pū ʻIa',
    'GR' => 'Helene',
    'IE' => 'ʻIlelani',
    'IL' => 'ʻIseraʻela',
    'IN' => 'ʻĪnia',
    'IT' => 'ʻĪkālia',
    'JP' => 'Iāpana',
    'MX' => 'Mekiko',
    'NL' => 'Hōlani',
    'NZ' => 'Aotearoa',
    'PH' => 'ʻĀina Pilipino',
    'RU' => 'Lūkia',
    'US' => 'ʻAmelika Hui Pū ʻIa',
];
