<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'BE' => 'ꀘꆹꏃ',
    'BR' => 'ꀠꑭ',
    'CN' => 'ꍏꇩ',
    'DE' => 'ꄓꇩ',
    'FR' => 'ꃔꇩ',
    'GB' => 'ꑱꇩ',
    'IN' => 'ꑴꄗ',
    'IT' => 'ꑴꄊꆺ',
    'JP' => 'ꏝꀪ',
    'MX' => 'ꃀꑭꇬ',
    'RU' => 'ꊉꇆꌦ',
    'US' => 'ꂰꇩ',
];
