<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AD' => 'Aŋdóra',
    'AE' => 'Yunaitɛ Arabhi Ɛmire',
    'AF' => 'Afigándesitaŋ',
    'AG' => 'Aŋtígwa Ɓahabhuda',
    'AI' => 'Aŋgíla',
    'AL' => 'Abhaniya',
    'AM' => 'Améniya',
    'AO' => 'Aŋgóla',
    'AR' => 'Ajɛŋtína',
    'AS' => 'Poo Sambowa',
    'AT' => 'Ɔ́situwa',
    'AU' => 'Ɔsituwéeliya',
    'AW' => 'Arubha',
    'AZ' => 'Azabhaijaŋ',
    'BA' => 'Bhɔsiniya',
    'BB' => 'Bhabhedo',
    'BD' => 'Bhangiladɛ̀shi',
    'BE' => 'Bhɛgiyɔŋ',
    'BF' => 'Bhokina Fáso',
    'BG' => 'Bhɔgeriya',
    'BH' => 'Bharɛŋ',
    'BI' => 'Bhurundi',
    'BJ' => 'Bhɛni',
    'BM' => 'Bhɛmuda',
    'BN' => 'Bhurunɛĩ',
    'BO' => 'Bholiviya',
    'BR' => 'Bhurazeli',
    'BS' => 'Bahámasi',
    'BT' => 'Bhutaŋ',
    'BW' => 'Bhosuwana',
    'BY' => 'Bhɛlarusi',
    'BZ' => 'Bheliz',
    'CA' => 'Kánáda',
    'CD' => 'Avorekoo',
    'CF' => 'Áfíríka Lumaã Tɛ Boloe',
    'CG' => 'Kóngo',
    'CH' => 'Suweza Lumaã',
    'CI' => 'Kódivówa',
    'CK' => 'Kóki Tiŋŋɛ',
    'CL' => 'Chéli',
    'CM' => 'Kameruŋ',
    'CN' => 'Cháína',
    'CO' => 'Kɔlɔmbiya',
    'CR' => 'Kósíta Ríko',
    'CU' => 'Kiyubha',
    'CV' => 'Kepi Vɛdi Tiŋŋɛ',
    'CY' => 'Saɛpurɔ',
    'CZ' => 'Chɛki Boloe',
    'DE' => 'Jamáĩ',
    'DJ' => 'Jibhuti',
    'DK' => 'Danimaha',
    'DM' => 'Domíiníka',
    'DO' => 'Domíiníka Ɓoloe',
    'DZ' => 'Agiriya',
    'EC' => 'Ɛ́kúwédɔ',
    'EE' => 'Ɛsitóninya',
    'EG' => 'Míséla',
    'ER' => 'Ɛritera',
    'ES' => 'Panyɛĩ',
    'ET' => 'Ítiyópiya',
    'FI' => 'Fiŋlɛŋ',
    'FJ' => 'Fíji',
    'FK' => 'Fáháki Luma Tiŋŋɛ',
    'FM' => 'Mikonisiya',
    'FR' => 'Fɛŋsi',
    'GA' => 'Gabhɔŋ',
    'GB' => 'Yunaitɛ Kíŋdɔŋ',
    'GD' => 'Gurinéda',
    'GE' => 'Jɔɔjiya',
    'GF' => 'Fɛŋsi Giwana',
    'GH' => 'Gana',
    'GI' => 'Jibhurata',
    'GL' => 'Jamba Kuwa Lumaã',
    'GM' => 'Gambiya',
    'GN' => 'Gini',
    'GP' => 'Guwadelupe',
    'GQ' => 'Dúúnyá Tɛ Giini',
    'GR' => 'Hɛlɛŋ',
    'GT' => 'Guwatɛmala',
    'GU' => 'Guwami',
    'GW' => 'Gini Bhisawo',
    'GY' => 'Guyana',
    'HN' => 'Hɔndura',
    'HR' => 'Koresiya',
    'HT' => 'Háiti',
    'HU' => 'Hɔ́ngare',
    'ID' => 'Índonisiya',
    'IE' => 'Áre Lumaã',
    'IL' => 'Bhanísiláila',
    'IN' => 'Índiya',
    'IQ' => 'Iraki',
    'IR' => 'Iraŋ',
    'IS' => 'Áisi Lumaã',
    'IT' => 'Ítali',
    'JM' => 'Jamaika',
    'JO' => 'Jɔɔdaŋ',
    'JP' => 'Japaŋ',
    'KE' => 'Kénya',
    'KG' => 'Kigisitaŋ',
    'KH' => 'Kaŋbhodiya',
    'KI' => 'Kiribhati',
    'KM' => 'Komorosi',
    'KN' => 'Siŋ Kisi ɓɛ́ Nevisi',
    'KP' => 'Koriya Kɔi Kaŋndɔ',
    'KR' => 'Koriya Kɔi Leŋŋɛ Lɔ',
    'KW' => 'Kuweti',
    'KY' => 'Keemaŋ Tiŋŋɛ',
    'KZ' => 'Kazasitaŋ',
    'LA' => 'Lawosi',
    'LB' => 'Lebhanɔ',
    'LC' => 'Siŋ Lusiya',
    'LK' => 'Suri Laŋka',
    'LR' => 'Laibhiya',
    'LS' => 'Lisóto',
    'LT' => 'Lituweninya',
    'LU' => 'Lusimbɔ',
    'LV' => 'Lativiya',
    'LY' => 'Lebhiya',
    'MA' => 'Mɔroko',
    'MC' => 'Mɔnako',
    'MD' => 'Mɔlidova',
    'MG' => 'Madagasita',
    'MH' => 'Masha Tiŋŋɛ',
    'ML' => 'Mali',
    'MM' => 'Miyamaha',
    'MN' => 'Mɔngoliya',
    'MP' => 'Kɔi Kaŋndɔ Mariyana Tiŋŋɛ',
    'MQ' => 'Matiniki',
    'MR' => 'Mɔretaninya',
    'MS' => 'Mɔserati',
    'MT' => 'Malita',
    'MU' => 'Mɔreshɔ',
    'MV' => 'Malidavi',
    'MW' => 'Malawi',
    'MX' => 'Mɛsíko',
    'MY' => 'Malesiya',
    'MZ' => 'Mozambiki',
    'NA' => 'Namibiya',
    'NC' => 'Kalidoninya Námaá',
    'NE' => 'Naĩja',
    'NF' => 'Nɔfɔ Tiŋŋɛ',
    'NG' => 'Naĩjiriya',
    'NI' => 'Nikaraguwa',
    'NL' => 'Nidɔlɛŋ',
    'NO' => 'Nɔɔwe',
    'NP' => 'Nepa',
    'NR' => 'Noru',
    'NU' => 'Niwe',
    'NZ' => 'Zilɛŋ Námaá',
    'OM' => 'Omaŋ',
    'PA' => 'Panama',
    'PE' => 'Pɛru',
    'PF' => 'Fɛŋsi Polinísiya',
    'PG' => 'Papuwa Gini Námaá',
    'PH' => 'Félepiŋ',
    'PK' => 'Pakisitaŋ',
    'PL' => 'Pólɛŋ',
    'PM' => 'Siŋ Piiyɛ ɓɛ́ Mikelɔŋ',
    'PN' => 'Pitikɛŋ',
    'PR' => 'Piyuto Riko',
    'PS' => 'Palesitininya Tele Jii Kɔiyɛ lá hĩ Gaza',
    'PT' => 'Potokíi',
    'PW' => 'Palo',
    'PY' => 'Paragɔe',
    'QA' => 'Kataha',
    'RE' => 'Renyɔɔ̃',
    'RO' => 'Romininya',
    'RU' => 'Rɔshiya',
    'RW' => 'Rawunda',
    'SA' => 'Lahabu',
    'SB' => 'Sulaimaãna Tiŋŋɛ',
    'SC' => 'Seshɛɛ',
    'SD' => 'Sudɛŋ',
    'SE' => 'Suwidɛŋ',
    'SG' => 'Síingapoo',
    'SH' => 'Siŋ Hɛlina',
    'SI' => 'Suloveninya',
    'SK' => 'Sulovakiya',
    'SL' => 'Gbeya Bahawɔ',
    'SM' => 'Saŋ Marindo',
    'SN' => 'Sinigaha',
    'SO' => 'Somaliya',
    'SR' => 'Surinambe',
    'ST' => 'Sawo Tombe ɓɛ a Gbawoe',
    'SV' => 'Ɛlɛ Sávádɔ',
    'SY' => 'Síyaŋ',
    'SZ' => 'Suwazi Lumaã',
    'TC' => 'Tukisi ɓɛ̀ Kaikóosi Tiŋŋɛ',
    'TD' => 'Chádi',
    'TG' => 'Togo',
    'TH' => 'Tai Lumaã',
    'TJ' => 'Tajikisitaŋ',
    'TK' => 'Tokelo',
    'TL' => 'Tele Ɓɔ́ Timɔɔ̃',
    'TM' => 'Tukimɛnisitaŋ',
    'TN' => 'Tunisiya',
    'TO' => 'Tɔnga',
    'TR' => 'Tɔ́ɔ́ki',
    'TT' => 'Turindeda ɓɛ́ Tobhego',
    'TV' => 'Tuválu',
    'TW' => 'Taiwaŋ',
    'TZ' => 'Taŋzaninya',
    'UA' => 'Yukuréŋ',
    'UG' => 'Yuganda',
    'US' => 'Poo',
    'UY' => 'Yuwegɔwe',
    'UZ' => 'Yubhɛkisitaŋ',
    'VA' => 'Vatikaŋ Ɓoloe',
    'VC' => 'Siŋ Viŋsi',
    'VE' => 'Vɛnɛzuwela',
    'VG' => 'Jengéesi Bhɛɛ Lɔ Musu Tiŋŋɛ',
    'VI' => 'Poo Bhɛɛ lɔ Musu Tiŋŋɛ',
    'VN' => 'Viyanami',
    'VU' => 'Vanuwátu',
    'WF' => 'Walísi',
    'WS' => 'Samowa',
    'YE' => 'Yemɛni',
    'YT' => 'Mavote',
    'ZA' => 'Afirika Kɔi Leŋŋɛ Lɔ',
    'ZM' => 'Zambiya',
    'ZW' => 'Zimbabhuwe',
];
