<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'острво Асенсион',
    'AX' => 'Оландска острва',
    'BL' => 'Сен Бартелеми',
    'BN' => 'Брунеји',
    'BY' => 'Бјелорусија',
    'CC' => 'Кокосова (Килинг) острва',
    'CZ' => 'Чешка Република',
    'DE' => 'Њемачка',
    'FK' => 'Фокландска острва',
    'FO' => 'Фарска острва',
    'GS' => 'Јужна Џорџија и Јужна Сендвичка острва',
    'GU' => 'Гвам',
    'GW' => 'Гвинеја Бисао',
    'HK' => 'Хонгконг (САО Кине)',
    'KM' => 'Комори',
    'KP' => 'Сјеверна Кореја',
    'MK' => 'Сјеверна Македонија',
    'MM' => 'Мјанмар (Бурма)',
    'MP' => 'Сјеверна Маријанска острва',
    'NF' => 'острво Норфок',
    'NU' => 'Нијуе',
    'PS' => 'палестинске територије',
    'RE' => 'Реунион',
    'TF' => 'Француске јужне територије',
    'UM' => 'Спољна острва САД',
    'VC' => 'Свети Винсент и Гренадини',
    'VG' => 'Британска Дјевичанска острва',
    'VI' => 'Америчка Дјевичанска острва',
];
