<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AD' => 'Andola',
    'AE' => 'Dimiliki dya Vakulungwa va Chalabu',
    'AF' => 'Afuganistani',
    'AG' => 'Antigua na Balbuda',
    'AI' => 'Angwila',
    'AL' => 'Albania',
    'AM' => 'Almenia',
    'AO' => 'Angola',
    'AR' => 'Adyentina',
    'AS' => 'Samoa ya Malekani',
    'AT' => 'Austlia',
    'AU' => 'Austlalia',
    'AW' => 'Aluba',
    'AZ' => 'Azabadyani',
    'BA' => 'Bosnia na Hezegovina',
    'BB' => 'Babadosi',
    'BD' => 'Bangladeshi',
    'BE' => 'Ubelgidi',
    'BF' => 'Buchinafaso',
    'BG' => 'Bulgalia',
    'BH' => 'Bahaleni',
    'BI' => 'Bulundi',
    'BJ' => 'Benini',
    'BM' => 'Belmuda',
    'BN' => 'Blunei',
    'BO' => 'Bolivia',
    'BR' => 'Blazili',
    'BS' => 'Bahama',
    'BT' => 'Butani',
    'BW' => 'Botswana',
    'BY' => 'Belalusi',
    'BZ' => 'Belize',
    'CA' => 'Kanada',
    'CD' => 'Jamuhuli ya Chidemoklasia ya kuKongo',
    'CF' => 'Jamuhuli ya Afilika ya Paching’ati',
    'CG' => 'Kongo',
    'CH' => 'Uswisi',
    'CI' => 'Kodivaa',
    'CK' => 'Chisiwa cha Cook',
    'CL' => 'Chile',
    'CM' => 'Kameluni',
    'CN' => 'China',
    'CO' => 'Kolombia',
    'CR' => 'Kostalika',
    'CU' => 'Kuba',
    'CV' => 'Kepuvede',
    'CY' => 'Kuplosi',
    'CZ' => 'Jamuhuli ya Chechi',
    'DE' => 'Udyerumani',
    'DJ' => 'Dyibuti',
    'DK' => 'Denmaki',
    'DM' => 'Dominika',
    'DO' => 'Jamuhuli ya Dominika',
    'DZ' => 'Aljelia',
    'EC' => 'Ekwado',
    'EE' => 'Estonia',
    'EG' => 'Misli',
    'ER' => 'Elitilea',
    'ES' => 'Hispania',
    'ET' => 'Uhabeshi',
    'FI' => 'Ufini',
    'FJ' => 'Fiji',
    'FK' => 'Chisiwa cha Falkland',
    'FM' => 'Mikilonesia',
    'FR' => 'Ufalansa',
    'GA' => 'Gaboni',
    'GB' => 'Nngalesa',
    'GD' => 'Glenada',
    'GE' => 'Dyodya',
    'GF' => 'Gwiyana ya Ufalansa',
    'GH' => 'Ghana',
    'GI' => 'Diblalta',
    'GL' => 'Glinlandi',
    'GM' => 'Gambia',
    'GN' => 'Gine',
    'GP' => 'Gwadelupe',
    'GQ' => 'Ginekweta',
    'GR' => 'Ugilichi',
    'GT' => 'Gwatemala',
    'GU' => 'Gwam',
    'GW' => 'Ginebisau',
    'GY' => 'Guyana',
    'HN' => 'Hondulasi',
    'HR' => 'Kolasia',
    'HT' => 'Haiti',
    'HU' => 'Hungalia',
    'ID' => 'Indonesia',
    'IE' => 'Ayalandi',
    'IL' => 'Islaeli',
    'IN' => 'India',
    'IQ' => 'Ilaki',
    'IR' => 'Uadyemi',
    'IS' => 'Aislandi',
    'IT' => 'Italia',
    'JM' => 'Dyamaika',
    'JO' => 'Yordani',
    'JP' => 'Dyapani',
    'KE' => 'Kenya',
    'KG' => 'Kiligizistani',
    'KH' => 'Kambodia',
    'KI' => 'Kilibati',
    'KM' => 'Komolo',
    'KN' => 'Santakitzi na Nevis',
    'KP' => 'Kolea Kasikazini',
    'KR' => 'Kolea Kusini',
    'KW' => 'Kuwaiti',
    'KY' => 'Chisiwa cha Kemen',
    'KZ' => 'Kazachistani',
    'LA' => 'Laosi',
    'LB' => 'Lebanoni',
    'LC' => 'Santalusia',
    'LI' => 'Lishenteni',
    'LK' => 'Sililanka',
    'LR' => 'Libelia',
    'LS' => 'Lesoto',
    'LT' => 'Litwania',
    'LU' => 'Lasembagi',
    'LV' => 'Lativia',
    'LY' => 'Libya',
    'MA' => 'Moloko',
    'MC' => 'Monako',
    'MD' => 'Moldova',
    'MG' => 'Bukini',
    'MH' => 'Chisiwa cha Malushal',
    'ML' => 'Mali',
    'MM' => 'Myama',
    'MN' => 'Mongolia',
    'MP' => 'Chisiwa cha Marian cha Kasikazini',
    'MQ' => 'Malitiniki',
    'MR' => 'Molitania',
    'MS' => 'Monselati',
    'MT' => 'Malta',
    'MU' => 'Molisi',
    'MV' => 'Modivu',
    'MW' => 'Malawi',
    'MX' => 'Meksiko',
    'MY' => 'Malesia',
    'MZ' => 'Msumbiji',
    'NA' => 'Namibia',
    'NC' => 'Nyukaledonia',
    'NE' => 'Nidyeli',
    'NF' => 'Chisiwa cha Nolufok',
    'NG' => 'Nidyelia',
    'NI' => 'Nikalagwa',
    'NL' => 'Uholanzi',
    'NO' => 'Norwe',
    'NP' => 'Nepali',
    'NR' => 'Naulu',
    'NU' => 'Niue',
    'NZ' => 'Nyuzilandi',
    'OM' => 'Omani',
    'PA' => 'Panama',
    'PE' => 'Pelu',
    'PF' => 'Polinesia ya Ufalansa',
    'PG' => 'Papua',
    'PH' => 'Filipino',
    'PK' => 'Pakistani',
    'PL' => 'Polandi',
    'PM' => 'Santapieli na Mikeloni',
    'PN' => 'Pitikeluni',
    'PR' => 'Pwetoliko',
    'PS' => 'Nchingu wa Magalibi wa Mpanda wa kuGaza wa kuPales',
    'PT' => 'Uleno',
    'PW' => 'Palau',
    'PY' => 'Palagwai',
    'QA' => 'Katali',
    'RE' => 'Liyunioni',
    'RO' => 'Lomania',
    'RU' => 'Ulusi',
    'RW' => 'Lwanda',
    'SA' => 'Saudia',
    'SB' => 'Chisiwa cha Solomon',
    'SC' => 'Shelisheli',
    'SD' => 'Sudani',
    'SE' => 'Uswidi',
    'SG' => 'Singapoo',
    'SH' => 'Santahelena',
    'SI' => 'Slovenia',
    'SK' => 'Slovakia',
    'SL' => 'Siela Leoni',
    'SM' => 'Samalino',
    'SN' => 'Senegali',
    'SO' => 'Somalia',
    'SR' => 'Sulinamu',
    'ST' => 'Saotome na Prinsipe',
    'SV' => 'Elsavado',
    'SY' => 'Silia',
    'SZ' => 'Uswazi',
    'TC' => 'Chisiwa cha Tuluchi na Kaiko',
    'TD' => 'Chadi',
    'TG' => 'Togo',
    'TH' => 'Tailandi',
    'TJ' => 'Tadikistani',
    'TK' => 'Tokelau',
    'TL' => 'Timoli ya Mashaliki',
    'TM' => 'Tuluchimenistani',
    'TN' => 'Tunisia',
    'TO' => 'Tonga',
    'TR' => 'Utuluchi',
    'TT' => 'Tilinidad na Tobago',
    'TV' => 'Tuvalu',
    'TW' => 'Taiwani',
    'TZ' => 'Tanzania',
    'UA' => 'Uklaini',
    'UG' => 'Uganda',
    'US' => 'Malekani',
    'UY' => 'Ulugwai',
    'UZ' => 'Uzibechistani',
    'VA' => 'Vatikani',
    'VC' => 'Santavisenti na Glenadini',
    'VE' => 'Venezuela',
    'VG' => 'Chisiwa Chivihi cha Wingalesa',
    'VI' => 'Chisiwa Chivihi cha Malekani',
    'VN' => 'Vietinamu',
    'VU' => 'Vanuatu',
    'WF' => 'Walis na Futuna',
    'WS' => 'Samoa',
    'YE' => 'Yemeni',
    'YT' => 'Maole',
    'ZA' => 'Afilika Kusini',
    'ZM' => 'Zambia',
    'ZW' => 'Zimbabwe',
];
