<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'BN' => 'Brunei',
    'BW' => 'Botswana',
    'CV' => 'Kapverden',
    'SB' => 'Salomon-Inseln',
    'TL' => 'Osttimor',
    'ZW' => 'Zimbabwe',
];
