<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Ile Ascension',
    'AD' => 'Andoor',
    'AE' => 'Emira Arab Ini',
    'AF' => 'Afganistaŋ',
    'AG' => 'Antiguwa ak Barbuda',
    'AI' => 'Angiiy',
    'AL' => 'Albani',
    'AM' => 'Armeni',
    'AO' => 'Àngolaa',
    'AQ' => 'Antarktik',
    'AR' => 'Arsàntin',
    'AS' => 'Samowa bu Amerig',
    'AT' => 'Ótiriis',
    'AU' => 'Ostarali',
    'AW' => 'Aruba',
    'AX' => 'Duni Aalànd',
    'AZ' => 'Aserbayjaŋ',
    'BA' => 'Bosni Ersegowin',
    'BB' => 'Barbad',
    'BD' => 'Bengalades',
    'BE' => 'Belsig',
    'BF' => 'Burkina Faaso',
    'BG' => 'Bilgari',
    'BH' => 'Bahreyin',
    'BI' => 'Burundi',
    'BJ' => 'Benee',
    'BL' => 'Saŋ Bartalemi',
    'BM' => 'Bermid',
    'BN' => 'Burney',
    'BO' => 'Boliwi',
    'BQ' => 'Pays-Bas bu Caraïbe',
    'BR' => 'Beresil',
    'BS' => 'Bahamas',
    'BT' => 'Butaŋ',
    'BW' => 'Botswana',
    'BY' => 'Belaris',
    'BZ' => 'Belis',
    'CA' => 'Kanadaa',
    'CC' => 'Duni Koko (Kilin)',
    'CD' => 'Kongo (R K D)',
    'CF' => 'Repiblik Sàntar Afrik',
    'CG' => 'Réewum Kongo',
    'CH' => 'Siwis',
    'CI' => 'Kodiwaar',
    'CK' => 'Duni Kuuk',
    'CL' => 'Sili',
    'CM' => 'Kamerun',
    'CN' => 'Siin',
    'CO' => 'Kolombi',
    'CR' => 'Kosta Rika',
    'CU' => 'Kuba',
    'CV' => 'Kabo Werde',
    'CW' => 'Kursawo',
    'CX' => 'Dunu Kirismas',
    'CY' => 'Siipar',
    'CZ' => 'Réewum Cek',
    'DE' => 'Almaañ',
    'DG' => 'Garsiya',
    'DJ' => 'Jibuti',
    'DK' => 'Danmàrk',
    'DM' => 'Dominik',
    'DO' => 'Repiblik Dominiken',
    'DZ' => 'Alseri',
    'EA' => 'Ceuta & Melilla',
    'EC' => 'Ekwaatër',
    'EE' => 'Estoni',
    'EG' => 'Esipt',
    'EH' => 'Sahara bu sowwu',
    'ER' => 'Eritere',
    'ES' => 'Españ',
    'ET' => 'Ecopi',
    'FI' => 'Finlànd',
    'FJ' => 'Fijji',
    'FK' => 'Duni Falkland',
    'FM' => 'Mikoronesi',
    'FO' => 'Duni Faro',
    'FR' => 'Faraans',
    'GA' => 'Gaboŋ',
    'GB' => 'Ruwaayom Ini',
    'GD' => 'Garanad',
    'GE' => 'Seworsi',
    'GF' => 'Guyaan Farañse',
    'GG' => 'Gernase',
    'GH' => 'Gana',
    'GI' => 'Sibraltaar',
    'GL' => 'Girinlànd',
    'GM' => 'Gàmbi',
    'GN' => 'Gine',
    'GP' => 'Guwaadelup',
    'GQ' => 'Gine Ekuwatoriyal',
    'GR' => 'Gerees',
    'GS' => 'Seworsi di Sid ak Duni Sàndwiis di Sid',
    'GT' => 'Guwatemala',
    'GU' => 'Guwam',
    'GW' => 'Gine-Bisaawóo',
    'GY' => 'Giyaan',
    'HK' => 'Ooŋ Koŋ',
    'HN' => 'Onduraas',
    'HR' => 'Korowasi',
    'HT' => 'Ayti',
    'HU' => 'Ongari',
    'IC' => 'Ile Canary',
    'ID' => 'Indonesi',
    'IE' => 'Irlànd',
    'IL' => 'Israyel',
    'IM' => 'Dunu Maan',
    'IN' => 'End',
    'IO' => 'Terituwaaru Brëtaañ ci Oseyaa Enjeŋ',
    'IQ' => 'Irag',
    'IR' => 'Iraŋ',
    'IS' => 'Islànd',
    'IT' => 'Itali',
    'JE' => 'Serse',
    'JM' => 'Samayig',
    'JO' => 'Sordani',
    'JP' => 'Sàppoŋ',
    'KE' => 'Keeña',
    'KG' => 'Kirgistaŋ',
    'KH' => 'Kàmboj',
    'KI' => 'Kiribati',
    'KM' => 'Komoor',
    'KN' => 'Saŋ Kits ak Newis',
    'KP' => 'Kore Noor',
    'KR' => 'Corée du Sud',
    'KW' => 'Kowet',
    'KY' => 'Duni Kaymaŋ',
    'KZ' => 'Kasaxstaŋ',
    'LA' => 'Lawos',
    'LB' => 'Libaa',
    'LC' => 'Saŋ Lusi',
    'LI' => 'Liktensteyin',
    'LK' => 'Siri Lànka',
    'LR' => 'Liberiya',
    'LS' => 'Lesoto',
    'LT' => 'Litiyani',
    'LU' => 'Liksàmbur',
    'LV' => 'Letoni',
    'LY' => 'Libi',
    'MA' => 'Marog',
    'MC' => 'Monako',
    'MD' => 'Moldawi',
    'ME' => 'Montenegoro',
    'MF' => 'Saŋ Marteŋ',
    'MG' => 'Madagaskaar',
    'MH' => 'Duni Marsaal',
    'MK' => 'Maseduwaan bëj Gànnaar',
    'ML' => 'Mali',
    'MM' => 'Miyanmaar',
    'MN' => 'Mongoli',
    'MO' => 'Makaawo',
    'MP' => 'Duni Mariyaan Noor',
    'MQ' => 'Martinik',
    'MR' => 'Mooritani',
    'MS' => 'Mooseraa',
    'MT' => 'Malt',
    'MU' => 'Moriis',
    'MV' => 'Maldiiw',
    'MW' => 'Malawi',
    'MX' => 'Meksiko',
    'MY' => 'Malesi',
    'MZ' => 'Mosàmbig',
    'NA' => 'Namibi',
    'NC' => 'Nuwel Kaledoni',
    'NE' => 'Niiseer',
    'NF' => 'Dunu Norfolk',
    'NG' => 'Niseriya',
    'NI' => 'Nikaraguwa',
    'NL' => 'Peyi Baa',
    'NO' => 'Norwees',
    'NP' => 'Nepaal',
    'NR' => 'Nawru',
    'NU' => 'Niw',
    'NZ' => 'Nuwel Selànd',
    'OM' => 'Omaan',
    'PA' => 'Panama',
    'PE' => 'Peru',
    'PF' => 'Polinesi Farañse',
    'PG' => 'Papuwasi Gine Gu Bees',
    'PH' => 'Filipin',
    'PK' => 'Pakistaŋ',
    'PL' => 'Poloñ',
    'PM' => 'Saŋ Peer ak Mikeloŋ',
    'PN' => 'Duni Pitkayirn',
    'PR' => 'Porto Riko',
    'PS' => 'réew yu Palestine',
    'PT' => 'Portigaal',
    'PW' => 'Palaw',
    'PY' => 'Paraguwe',
    'QA' => 'Kataar',
    'RE' => 'Reeñoo',
    'RO' => 'Rumani',
    'RS' => 'Serbi',
    'RU' => 'Risi',
    'RW' => 'Ruwànda',
    'SA' => 'Arabi Sawudi',
    'SB' => 'Duni Salmoon',
    'SC' => 'Seysel',
    'SD' => 'Sudaŋ',
    'SE' => 'Suwed',
    'SG' => 'Singapuur',
    'SH' => 'Saŋ Eleen',
    'SI' => 'Esloweni',
    'SJ' => 'Swalbaar ak Jan Mayen',
    'SK' => 'Eslowaki',
    'SL' => 'Siyera Lewon',
    'SM' => 'San Marino',
    'SN' => 'Senegaal',
    'SO' => 'Somali',
    'SR' => 'Sirinam',
    'SS' => 'Sudaŋ di Sid',
    'ST' => 'Sawo Tome ak Pirinsipe',
    'SV' => 'El Salwadoor',
    'SX' => 'Sin Marten',
    'SY' => 'Siri',
    'SZ' => 'Suwasilànd',
    'TA' => 'Tristan da Cunha',
    'TC' => 'Duni Tirk ak Kaykos',
    'TD' => 'Càdd',
    'TF' => 'Teer Ostraal gu Fraas',
    'TG' => 'Togo',
    'TH' => 'Taylànd',
    'TJ' => 'Tajikistaŋ',
    'TK' => 'Tokoloo',
    'TL' => 'Timor Leste',
    'TM' => 'Tirkmenistaŋ',
    'TN' => 'Tinisi',
    'TO' => 'Tonga',
    'TR' => 'Tirki',
    'TT' => 'Tirinite ak Tobago',
    'TV' => 'Tuwalo',
    'TW' => 'Taywan',
    'TZ' => 'Taŋsani',
    'UA' => 'Ikeren',
    'UG' => 'Ugànda',
    'UM' => 'Duni Amerig Utar meer',
    'US' => 'Etaa Sini',
    'UY' => 'Uruge',
    'UZ' => 'Usbekistaŋ',
    'VA' => 'Site bu Watikaa',
    'VC' => 'Saŋ Weesaa ak Garanadin',
    'VE' => 'Wenesiyela',
    'VG' => 'Duni Wirsin yu Brëtaañ',
    'VI' => 'Duni Wirsin yu Etaa-sini',
    'VN' => 'Wiyetnam',
    'VU' => 'Wanuatu',
    'WF' => 'Walis ak Futuna',
    'WS' => 'Samowa',
    'XK' => 'Kosowo',
    'YE' => 'Yaman',
    'YT' => 'Mayot',
    'ZA' => 'Afrik di Sid',
    'ZM' => 'Sàmbi',
    'ZW' => 'Simbabwe',
];
