<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'BR' => 'ব্রাজিল',
    'CN' => 'চিনা',
    'DE' => 'জর্মনি',
    'FR' => 'ফ্রান্স',
    'GB' => 'য়ুনাইটেদ কিংদম',
    'IN' => 'ইন্দিয়া',
    'IT' => 'ইটালি',
    'JP' => 'জাপান',
    'RU' => 'রুসিয়া',
    'US' => 'য়ুনাইটেদ ষ্টেটস',
];
