<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'BR' => 'Бразили',
    'CN' => 'Китай',
    'DE' => 'Герман',
    'FR' => 'Франц',
    'GB' => 'Стыр Британи',
    'GE' => 'Гуырдзыстон',
    'IN' => 'Инди',
    'IT' => 'Итали',
    'JP' => 'Япон',
    'RU' => 'Уӕрӕсе',
    'US' => 'АИШ',
];
