<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Asɛnsiyɔɔn kaAtukǝltǝna',
    'AD' => 'Anɖɔraa',
    'AE' => 'Emiir baGanɔ gaɖɔŋkɔnɔ kaAlaaributǝna',
    'AF' => 'Afganistan',
    'AG' => 'Antiguwaa na Barbuɖaa',
    'AI' => 'Aŋguwilaa',
    'AL' => 'Albanii',
    'AM' => 'Armenii',
    'AO' => 'Aŋgolaa',
    'AQ' => 'Gatutaltǝna',
    'AR' => 'Arjantin',
    'AS' => 'Samowa Amalɩka kaja',
    'AT' => 'Otrish',
    'AU' => 'Ɔstraliya',
    'AW' => 'Arubaa',
    'AX' => 'Ɔɔlanɖ kaBʊtǝlǝltǝna',
    'AZ' => 'Asɛrbaɩjaŋ',
    'BA' => 'Bɔsniya na Hɛrsegɔfina',
    'BB' => 'Barbaɖɔɔsɩ',
    'BD' => 'Baŋglaɖɛɛshɩ',
    'BE' => 'Bɛljiiki',
    'BF' => 'Burkinaa',
    'BG' => 'Bulgarii',
    'BH' => 'Barɛɛn',
    'BI' => 'Burunɖii',
    'BJ' => 'Benɛɛ',
    'BL' => 'Sɛŋ-Batolomayɔ',
    'BM' => 'Bɛrmuɖaa',
    'BN' => 'Brunɛɩ',
    'BO' => 'Bolifiya',
    'BQ' => 'Holanɖ kaKarayiib',
    'BR' => 'Bresil',
    'BS' => 'Bahamaasɩ',
    'BT' => 'Butan',
    'BW' => 'Bɔsʊwanaa',
    'BY' => 'Belaruus',
    'BZ' => 'Beliis',
    'CA' => 'Kanaɖaa',
    'CC' => 'Kokoos (Kiiliŋ) kaBʊtukǝltǝna',
    'CD' => 'Koŋgoo Kinshasaa',
    'CF' => 'Santrafrika',
    'CG' => 'Koŋgoo Brasafil',
    'CH' => 'Suwis',
    'CI' => 'Koɖifʊaa',
    'CK' => 'Kʊkʊ kaBʊtukǝltǝna',
    'CL' => 'Shilii',
    'CM' => 'Kamerun',
    'CN' => 'Caɩna',
    'CO' => 'Kolɔmbii',
    'CQ' => 'Sark',
    'CR' => 'Kɔsta Rikaa',
    'CU' => 'Kubaa',
    'CV' => 'Kapfɛɛr',
    'CW' => 'Kurasawuu',
    'CX' => 'Nowɛl kaAtukǝltǝna',
    'CY' => 'Ciprɔs',
    'CZ' => 'Cɛk',
    'DE' => 'Gajaamatǝna',
    'DG' => 'Ɖiyego Garsiya',
    'DJ' => 'Jibutii',
    'DK' => 'Ɖanǝmark',
    'DM' => 'Ɖominikaa',
    'DO' => 'Ɖominikaa kaRepibliiki',
    'DZ' => 'Aljerii',
    'EA' => 'Seyuta na Meliliya',
    'EC' => 'Ekuwaɖɔɔr',
    'EE' => 'Ɛstoniya',
    'EG' => 'Ejipti',
    'EH' => 'Sarawii',
    'ER' => 'Eritree',
    'ES' => 'Ɛspanyǝ',
    'ET' => 'Etiyopii',
    'FI' => 'Fɛnlanɖ',
    'FJ' => 'Fiji',
    'FK' => 'Fɔklanɖ kaBʊtukǝltǝna',
    'FM' => 'Mikronesiya',
    'FO' => 'Faroi kaBʊtukǝltǝna',
    'FR' => 'Gafɔntǝna',
    'GA' => 'Gabɔŋ',
    'GB' => 'Gagɛɛshɩtǝna',
    'GD' => 'Grenaɖaa',
    'GE' => 'Jɔrjiya',
    'GF' => 'Guyanaa Gafɔntǝna kaja',
    'GG' => 'Gǝrǝnsɛɩ',
    'GH' => 'Gana',
    'GI' => 'Gibraltaa',
    'GL' => 'Grinlanɖ',
    'GM' => 'Gambii',
    'GN' => 'Ginee',
    'GP' => 'Guwaɖeluupu',
    'GQ' => 'Ginee Malabo',
    'GR' => 'Grɛs',
    'GS' => 'Jɔrjiya gʊnyɩsonolaŋ kaja na Sanɖuush gʊnyɩsonolaŋ kaBʊtukǝltǝna',
    'GT' => 'Guwatemalaa',
    'GU' => 'Guwam',
    'GW' => 'Ginee Bisoo',
    'GY' => 'Guyanaa',
    'HK' => 'Hɔŋ Kɔŋ Caɩna kaja',
    'HN' => 'Hɔnɖuraasɩ',
    'HR' => 'Krowasii',
    'HT' => 'Hayitii',
    'HU' => 'Ɔŋgrii',
    'IC' => 'Kanarii kaBʊtukǝltǝna',
    'ID' => 'Ɛnɖonosii',
    'IE' => 'Irlanɖ',
    'IL' => 'Yishraɛl',
    'IM' => 'Man kaAtukǝltǝna',
    'IN' => 'Inɖiya',
    'IO' => 'Gɛɛshɩ kaAtǝna Inɖiya kaTeŋku nɩ',
    'IQ' => 'Ɩraakɩ',
    'IR' => 'Iraŋ',
    'IS' => 'Islanɖ',
    'IT' => 'Italii',
    'JE' => 'Jersei',
    'JM' => 'Jamaɩka',
    'JO' => 'Jɔrɖanii',
    'JP' => 'Japaŋ',
    'KE' => 'Keniya',
    'KG' => 'Kirgistan',
    'KH' => 'Kamboɖiya',
    'KI' => 'Kiribatii',
    'KM' => 'Komɔɔr',
    'KN' => 'Sɛŋ Kits na Nefis',
    'KP' => 'Koree gʊnyɩpɛnɛlaŋ',
    'KR' => 'Koree gʊnyɩsonolaŋ',
    'KW' => 'Koweeti',
    'KY' => 'Kayimaan kaBʊtukǝltǝna',
    'KZ' => 'Kasastan',
    'LA' => 'Lawɔs',
    'LB' => 'Liibaaŋ',
    'LC' => 'Sɛŋ Lusiya',
    'LI' => 'Liishtɛntaɩn',
    'LK' => 'Siri Laŋkaa',
    'LR' => 'Liberiya',
    'LS' => 'Lesotoo',
    'LT' => 'Lituwaniya',
    'LU' => 'Lusɛmbuur',
    'LV' => 'Lɛtfiya',
    'LY' => 'Libii',
    'MA' => 'Morooko',
    'MC' => 'Monakoo',
    'MD' => 'Mɔlɖafiya',
    'ME' => 'Mɔntenegroo',
    'MF' => 'Sɛŋ Martɛɛŋ',
    'MG' => 'Maɖagaskaa',
    'MH' => 'Marshal kaBʊtukǝltǝna',
    'MK' => 'Maseɖoniya gʊnyɩpɛnɛlaŋ kaja',
    'ML' => 'Malii',
    'MM' => 'Miyanmaa (Birmanii)',
    'MN' => 'Mɔŋgolii',
    'MO' => 'Makawoo Caɩna kaja',
    'MP' => 'Mariyan kaBʊtukǝltǝna gʊnyɩpɛnɛlaŋ',
    'MQ' => 'Martiniiki',
    'MR' => 'Moritanii',
    'MS' => 'Mɔnsɛraatɩ',
    'MT' => 'Malta',
    'MU' => 'Imoris',
    'MV' => 'Malɖiifu',
    'MW' => 'Malawii',
    'MX' => 'Mɛsik',
    'MY' => 'Malɛsii',
    'MZ' => 'Mosambii',
    'NA' => 'Namibii',
    'NC' => 'Kaleɖonii afɔlɩ',
    'NE' => 'Nijɛr',
    'NF' => 'Nɔrfook kaAtukǝltǝna',
    'NG' => 'Nanjiiriya',
    'NI' => 'Nikaraguwaa',
    'NL' => 'Holanɖ',
    'NO' => 'Nɔrfɛsh',
    'NP' => 'Neepal',
    'NR' => 'Nawuru',
    'NU' => 'Niwuye',
    'NZ' => 'Selanɖ afɔlɩ',
    'OM' => 'Oman',
    'PA' => 'Panamaa',
    'PE' => 'Peruu',
    'PF' => 'Polinesiya Gafɔntǝna kaja',
    'PG' => 'Papuasii Ginee afɔlɩ',
    'PH' => 'Filipiin',
    'PK' => 'Pakistan',
    'PL' => 'Polanɖ',
    'PM' => 'Sɛŋ-Petrɔs na Mikelɔŋ',
    'PN' => 'Pɩtkɛɛn kaBʊtukǝltǝna',
    'PR' => 'Pɔrto Rikoo',
    'PS' => 'Palɛstiin kAsàʊ',
    'PT' => 'Pɔrtigal',
    'PW' => 'Palawoo',
    'PY' => 'Paraguwee',
    'QA' => 'Kataa',
    'RE' => 'Reeniyɔŋ',
    'RO' => 'Romanii',
    'RS' => 'Sɛrbii',
    'RU' => 'Rɔɔshɩya',
    'RW' => 'Rʊwanɖaa',
    'SA' => 'Sauɖiya',
    'SB' => 'Salomɔɔn kaBʊtukǝltǝna',
    'SC' => 'Seshɛl',
    'SD' => 'Suɖaŋ',
    'SE' => 'Sʊwɛɖ',
    'SG' => 'Siŋgapuur',
    'SH' => 'Sɛŋ Elenaa (kaAtukǝltǝna)',
    'SI' => 'Slofeniya',
    'SJ' => 'Sǝfalbaaɖ na Yan Mayɛn',
    'SK' => 'Slofakii',
    'SL' => 'Seraleyɔn',
    'SM' => 'Sɛŋ Marinoo',
    'SN' => 'Senegal',
    'SO' => 'Somalii',
    'SR' => 'Surinam',
    'SS' => 'Suɖaŋ gʊnyɩsonolaŋ',
    'ST' => 'Saotomee',
    'SV' => 'Ɛl Salfaɖɔɔr',
    'SX' => 'Sɛŋ Martɛɛŋ (Holanɖ kaja)',
    'SY' => 'Sirii',
    'SZ' => 'Ɛsʊwatinii',
    'TA' => 'Tristan ɖa Kuna',
    'TC' => 'Turkisii na Kayɩkɔɔsɩ kaBʊtukǝltǝna',
    'TD' => 'Caɖ',
    'TF' => 'Gafɔntǝna kaBʊtǝna gʊnyɩsonolaŋ kabʊja',
    'TG' => 'Togoo',
    'TH' => 'Taɩlanɖ',
    'TJ' => 'Tajikistan',
    'TK' => 'Tokelaʊ',
    'TL' => 'Timɔɔ gajakalaŋ',
    'TM' => 'Turkmenistan',
    'TN' => 'Tunisii',
    'TO' => 'Tɔŋga',
    'TR' => 'Turkii',
    'TT' => 'Triniɖaaɖ na Tobagoo',
    'TV' => 'Tufalu',
    'TW' => 'Taɩwan',
    'TZ' => 'Taŋsanii',
    'UA' => 'Ikrɛɛn',
    'UG' => 'Uganɖaa',
    'UM' => 'Ganɔ gaɖɔŋkɔnɔ kaBʊtǝna Amalɩka nɩ kaBʊtukǝltǝna bʊlǝŋka',
    'US' => 'Ganɔ gaɖɔŋkɔnɔ kaBʊtǝna Amalɩka nɩ',
    'UY' => 'Uruguwee',
    'UZ' => 'Usbeekistan',
    'VA' => 'Fatikaŋ kaMpá',
    'VC' => 'Sɛŋ Fɩnsaŋ na Grenaɖiniisi',
    'VE' => 'Fenesuwelaa',
    'VG' => 'Fɩrjɩɩn kǝBʊtukǝltǝna Gɛɛshɩ kabʊja',
    'VI' => 'Fɩrjɩɩn kaBʊtukǝltǝna Amalɩka kabʊja',
    'VN' => 'Fɛtnam',
    'VU' => 'Fanuwatu',
    'WF' => 'Walis na Futuna',
    'WS' => 'Samowa',
    'XK' => 'Kɔsofoo',
    'YE' => 'Yemɛn',
    'YT' => 'Mayɔɔtɩ',
    'ZA' => 'Sautafrika',
    'ZM' => 'Sambii',
    'ZW' => 'Simbabʊwee',
];
